==> sync2jira-0.1.tar.gz: sync2jira-0.1/fedmsg.d/sync2jira.py <==
# This file is part of sync2jira.
# Copyright (C) 2016 Red Hat, Inc.
#
# sync2jira is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# sync2jira is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with sync2jira; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110.15.0 USA
#
# Authors:  Ralph Bean <rbean@redhat.com>

config = {
    'sync2jira': {
        'initialize': True,
        'testing': True,
        'jira': {
            'options': {
                'server': 'https://some_jira_server_somewhere.com',
                'verify': True,
            },
            'basic_auth': ('YOUR_USERNAME', 'YOUR_PASSWORD'),
        },
        'map': {
            'pagure': {
                'pungi': { 'project': 'COMPOSE', 'component': 'Pungi', },
                #'koji': { 'project': 'RCMPROJ', 'component': 'Brew', },
            },
            'github': {
                #'product-definition-center/product-definition-center': {
                #    'project': 'PDC', 'component': 'General', },
                #'product-definition-center/pdc-client': {
                #    'project': 'PDC', 'component': 'General', },
            },
        },
    },
    'logging': dict(
        version=1,
        loggers=dict(
            sync2jira={
                "level": "INFO",
                "propagate": True,
            },
        ),
    ),
}

==> sync2jira-0.2.tar.gz: sync2jira-0.2/fedmsg.d/sync2jira.py <==
# This file is part of sync2jira.
# Copyright (C) 2016 Red Hat, Inc.
#
# sync2jira is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# sync2jira is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with sync2jira; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110.15.0 USA
#
# Authors:  Ralph Bean <rbean@redhat.com>

config = {
    'sync2jira': {
        'initialize': True,
        'testing': True,
        'jira': {
            'options': {
                'server': 'https://some_jira_server_somewhere.com',
                'verify': True,
            },
            'basic_auth': ('YOUR_USERNAME', 'YOUR_PASSWORD'),
        },
        'map': {
            'pagure': {
                'pungi': { 'project': 'COMPOSE', 'component': 'Pungi', },
                #'koji': { 'project': 'BREW', 'component': None, },
            },
            'github': {
                #'product-definition-center/product-definition-center': {
                #    'project': 'PDC', 'component': 'General', },
                #'product-definition-center/pdc-client': {
                #    'project': 'PDC', 'component': 'General', },
            },
        },
    },
    'logging': dict(
        version=1,
        loggers=dict(
            sync2jira={
                "level": "INFO",
                "propagate": True,
            },
        ),
    ),
}
